@@ -464,7 +464,7 @@ if (Config.PsxOut) printf ("save started;\n");
 	gzwrite(f, gpufP, sizeof(GPUFreeze));
 	free(gpufP);
 
-	if (Config.PsxOut) printf ("spu save;\n");
+/*	if (Config.PsxOut) printf ("spu save;\n");
 	// spu
 	spufP = (SPUFreeze_t *) malloc(16);
 	SPU_freeze(2, spufP);
@@ -473,7 +473,7 @@ if (Config.PsxOut) printf ("save started;\n");
 	spufP = (SPUFreeze_t *) malloc(Size);
 	SPU_freeze(1, spufP);
 	gzwrite(f, spufP, Size);
-	free(spufP);
+	free(spufP);*/
 
 	if (Config.PsxOut) printf ("freezing;\n");
 	sioFreeze(f, 1);
@@ -518,11 +518,11 @@ int LoadState(char *file) {
 	free(gpufP);
 
 	// spu
-	gzread(f, &Size, 4);
+/*	gzread(f, &Size, 4);
 	spufP = (SPUFreeze_t *) malloc (Size);
 	gzread(f, spufP, Size);
 	SPU_freeze(0, spufP);
-	free(spufP);
+	free(spufP);*/
 
 	sioFreeze(f, 0);
 	cdrFreeze(f, 0);
